/* CSVRowWriter.cpp

This file contains the methods for the CSVRowWriter class
used in XMLToCSVBasic

From Chapter 2 of
Using XML with Legacy Business Applications
Copyright (c) 2002 Addison-Wesley Professional

Author: Michael C. Rawlins
Rawlins EC Consulting
PMB 29
14 Canyon Creek Village
Richardson, TX 75080-1602
mike@rawlinsecconsulting.com
972-783-9573

This file is one of several utilities developed for the book.

All utilities developed for the book are free software; you can
redistribute and/or modify them under the terms of the GNU
General Public License, Version 2, as published by the Free
Software Foundation.

These utilities are distributed in the hope that they will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with XMLToCSVBasic; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston,
MA  02111-1307  USA

The license is also available on the World Wide Web at
http://www.gnu.org/licenses/gpl.html

*/

//  Common header files
#include "BlasterIncludes.h"
#include "CSVRowWriter.h"


//  Constructor
CSVRowWriter::CSVRowWriter(ofstream * inOutputCSV)
{
  OutputCSV = inOutputCSV;
}

//  Destructor
CSVRowWriter::~CSVRowWriter() {};


//  write - Write a Row to the file from a Row
//  Element and children
void CSVRowWriter::write(IXMLDOMElementPtr spRow)
{
  // Local Variables
  char * cColumnArray[MAXCOLUMNS+1];

  IXMLDOMNodeListPtr spColumnList;

  char cColumnName[9];
  char cColumnNumber[3];
  char cOutputBuffer[OUTPUTBUFFERSIZE];
  int iRowChildren, iColumnNumber, iHighestColumn, i;;

  iRowChildren = 0;
  iHighestColumn = 0;

  //  Initialize columns array
  for (i = 0; i < MAXCOLUMNS+1; i++)
  {
    cColumnArray[i] = NULL;
  }

  //  Columns NodeList <- Get Row's childNodes attribute
  spColumnList = spRow->childNodes;

  //  DO until Columns NodeList.item[index] is null
  while (spColumnList->item[iRowChildren] != NULL)
  {
    // Get a shorthand name for this guy
    IXMLDOMNodePtr spColumn;
    spColumn = spColumnList->item[iRowChildren];

    //  Column Name <- get NodeName attribute
    strcpy(cColumnName,spColumn->nodeName);

    //  Column Number <- Derive from Column Name
    strcpy(cColumnNumber,&(cColumnName[6]));
    iColumnNumber = atoi(cColumnNumber);

    //  IF Column Number > Highest Column
    //    Highest Column <- Column Number
    //  ENDIF
    if (iColumnNumber > iHighestColumn)
    {
      iHighestColumn = iColumnNumber;
    }

    //  Get memory for this column entry, and init it
    if (cColumnArray[iColumnNumber] == NULL)
    {
      cColumnArray[iColumnNumber] = new char[MAXCOLUMNSIZE];
      memset(cColumnArray[iColumnNumber],'\0',MAXCOLUMNSIZE);
    }
    
    //  Column Array [Column Number] <- get nodeValue of
    //    item[index] firstChild Node
    //  GetnodeValue is returned as a COM VARIANT, so we
    //  use _bstr_t to get to the character text

    strcpy(cColumnArray[iColumnNumber],
       _bstr_t(spColumn->firstChild->GetnodeValue()));

    //  Increment index
    iRowChildren++;
  
  } //  ENDDO

  //  Output Buffer <- Call FormatRow, passing Column Array and
  //    Highest Column
  //  For C++ we also pass the output buffer
  formatRow(cColumnArray, iHighestColumn, cOutputBuffer);

  //  Write Output Buffer
  *OutputCSV << cOutputBuffer << endl;

  return;
}  
  
//  formatRow - Format the column array entries into a buffer

void CSVRowWriter::formatRow(char * cColumnArray[],
  int iHighestColumn, char * cOutputBuffer)
{
  int i;

  memset(cOutputBuffer,'\0',OUTPUTBUFFERSIZE);

  for ( i = 1; i <= iHighestColumn; i++ )
  {
    //  Append the column text if present
    if (cColumnArray[i] != NULL)
    {
      strcat(cOutputBuffer,"\"");
      strcat(cOutputBuffer,cColumnArray[i]);
      strcat(cOutputBuffer,"\"");

      // We're finished with this guy, so free the memory
      delete cColumnArray[i];
    }

    //  Put in the comma separator unless we've hit the
    //  highest column
    if ( i < iHighestColumn )
    {
      strcat(cOutputBuffer,",");
    }
  }
  
  return;
}  
