/* FlatTargetConverter.cpp

Drives conversion from XML to flat files

From Chapter 8 of
Using XML with Legacy Business Applications
Copyright (c) 2002 Addison-Wesley Professional

Author: Michael C. Rawlins
Rawlins EC Consulting
PMB 29
14 Canyon Creek Village
Richardson, TX 75080-1602
mike@rawlinsecconsulting.com
972-783-9573

This file is one of several utilities developed for the book.

All utilities developed for the book are free software; you can
redistribute and/or modify them under the terms of the GNU
General Public License, Version 2, as published by the Free
Software Foundation.

These utilities are distributed in the hope that they will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with the book; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston,
MA  02111-1307  USA

The license is also available on the World Wide Web at
http://www.gnu.org/licenses/gpl.html

*/

//  Common header files
#include "BlasterIncludes.h"
#include "BlasterPrototypes.h"


//  Special headers for this module only
#include "FlatRecordWriter.h"
#include "FlatTargetConverter.h"
#include <strstrea.h>


//  Default Constructor
FlatTargetConverter::FlatTargetConverter(
     const char * const cFileDescriptionDocumentName,
     ofstream * const OutputStream) : 
     TargetConverter(cFileDescriptionDocumentName)
{
  //  call base class constructor, passing
  //    File Description Document Name

  //  Create FlatRecordWriter object, passing:
  //    File Description Document DOM and output stream
  Writer = new FlatRecordWriter(spFileDescription,
      OutputStream);
}


//  Destructor
FlatTargetConverter::~FlatTargetConverter()
{
  delete Writer;
}

//  Process a Document
int FlatTargetConverter::processDocument(
    const IXMLDOMDocument2Ptr spDocInput)
{
  //  Locals
  IXMLDOMElementPtr spRootElement;
  char cInputRootElementName[NMTOKEN_SIZE];
  int iReturn;

  memset(cInputRootElementName, 0, sizeof(cInputRootElementName));

  //  Root Element <- Get Document's documentElement attribute
  spRootElement = spDocInput->documentElement;

  //  Root Element Name <- Get Root Element's tagName attribute
  _bstr_t bstrInputRootElementName(spRootElement->tagName);

  //  IF Root Element Name != Grammar Root Element Name
  if ( !(strcmp(cRootElementName,
         (char *) bstrInputRootElementName) == 0) )
  {
    //  Return error
    cerr << bstrInputRootElementName << ROOT_MISMATCH 
         << cRootElementName << endl;
    return FAILURE;
  } //  ENDIF


  //  Call processGroup, passing Root Element and Grammar
  //    Element
  iReturn = processGroup(spRootElement, spGrammar);

  //  Return success
  return iReturn;
}
