/* Converter.cpp

Base class for base Converter class

From Chapter 6 of
Using XML with Legacy Business Applications
Copyright (c) 2002 Addison-Wesley Professional

Author: Michael C. Rawlins
Rawlins EC Consulting
PMB 29
14 Canyon Creek Village
Richardson, TX 75080-1602
mike@rawlinsecconsulting.com
972-783-9573

This file is one of several utilities developed for the book.

All utilities developed for the book are free software; you can
redistribute and/or modify them under the terms of the GNU
General Public License, Version 2, as published by the Free
Software Foundation.

These utilities are distributed in the hope that they will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with the book; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston,
MA  02111-1307  USA

The license is also available on the World Wide Web at
http://www.gnu.org/licenses/gpl.html

*/

//  Common header files
#include "BlasterIncludes.h"
#include "BlasterPrototypes.h"


//  Special headers for this module only
#include <strstrea.h>


//  Default Constructor
Converter::Converter()
{
#include "BlasterExceptions.h"
  //  Set up implementation dependent environment for loading
  //  and parsing the FileDescription Document

  //  Locals

  //  COM
  HRESULT hResult;

  //  Basic types

  //  Create the COM DOM Document object
  hResult = spFileDescription.CreateInstance(
    __uuidof(DOMDocument40));

  if FAILED(hResult)
  {
    throw cCreateInstanceError;
  }

  //  Tell it we don't want to load the document asynchronously
  spFileDescription->async =  VARIANT_FALSE; 


  //  Make sure that we validate on parse
  spFileDescription->validateOnParse = VARIANT_TRUE;

}


//  Destructor
Converter::~Converter() {};

//  Load the File Description Document
int Converter::loadFileDescriptionDocument(
    const char * const cFileDescriptionDocumentName)
{
  //  Locals

  //  COM
  HRESULT hResult;

  //  Basic types

  //  XML
  IXMLDOMParseErrorPtr spParseError;

  //  Load input XML Document (dependent on implementation)
  hResult = spFileDescription->load(
      cFileDescriptionDocumentName);
  
  // Check for errors
  if( hResult != VARIANT_TRUE)
  {
    spParseError = spFileDescription->GetparseError();
    cerr << PARSE_ERROR_BRIEF << cFileDescriptionDocumentName 
        << endl;
    displayParseError(spParseError);
    return FAILURE;
  }

  //  Validate the File Description Document - we do this to make
  //    sure there's a schema reference
  spParseError = spFileDescription->validate();
  if( spParseError->errorCode != S_OK)
  {
    cerr << VALIDATION_ERROR_BRIEF 
      << cFileDescriptionDocumentName << endl;
    displayParseError(spParseError);
    return FAILURE;
  }


  //  Grammar Element <- call File Description Document's
  //    GetElementsByTagName for "Grammar"
  spGrammar = 
    spFileDescription->getElementsByTagName("Grammar")->item[0];

  //  Root Element Name <- call Grammar Element's getAttribute
  //    on "ElementName"
  memset(cRootElementName,0,sizeof(cRootElementName));
  strcpy(cRootElementName, 
    _bstr_t(spGrammar->getAttribute("ElementName")) );

  return SUCCESS;
}