/* DataCell.h

Header file for base DataCell class

From Chapter 6 of
Using XML with Legacy Business Applications
Copyright (c) 2002 Addison-Wesley Professional

Author: Michael C. Rawlins
Rawlins EC Consulting
PMB 29
14 Canyon Creek Village
Richardson, TX 75080-1602
mike@rawlinsecconsulting.com
972-783-9573

This file is one of several utilities developed for the book.

All utilities developed for the book are free software; you can
redistribute and/or modify them under the terms of the GNU
General Public License, Version 2, as published by the Free
Software Foundation.

These utilities are distributed in the hope that they will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with the book; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston,
MA  02111-1307  USA

The license is also available on the World Wide Web at
http://www.gnu.org/licenses/gpl.html

*/

#ifndef DATACELL_H
#define DATACELL_H


class DataCell
{
public:
  DataCell(int iFieldNumberIn,
    const IXMLDOMElementPtr spGrammarIn);
  ~DataCell();
  void clearField();
  bool delimitText();
  void fillField(const char cJustify, const int iFieldLength);
  int getField(char * const cFieldContents);
  int getFieldNumber();
  int getSubFieldNumber();
  int getLength();
  void getName(char * const cElementName);
  void justifyFieldLeft(const int iFieldLength, const char cFill);
  void justifyFieldRight(const int iFieldLength, const char cFill);
  int putField(const char * const cFieldContents, int iFieldLength);
  int putByte(char cFieldByte);
  void setSubFieldNumber(int iSubFieldNumber);
  void toElement(const IXMLDOMDocument2Ptr spDocument,
    const IXMLDOMElementPtr spParent);
  void trim();
  void trimLeadingZeroes();

  //  Virtual functions for derived classes
  virtual int fromXML();
  virtual int prepareOutput();
  virtual int toXML();

protected:
  //  XML
  IXMLDOMElementPtr spGrammar;

  //  Basic types
  char cCellBuffer[CELL_BUFFER_SIZE];
  int iBufferLength;
  int iFieldNumber;
  int iSubFieldNumber;
};


#endif
