/* DataCellAN.cpp

For handling of AlphaNumeric fields in non-XML files

From Chapter 7 of
Using XML with Legacy Business Applications
Copyright (c) 2002 Addison-Wesley Professional

Author: Michael C. Rawlins
Rawlins EC Consulting
PMB 29
14 Canyon Creek Village
Richardson, TX 75080-1602
mike@rawlinsecconsulting.com
972-783-9573

This file is one of several utilities developed for the book.

All utilities developed for the book are free software; you can
redistribute and/or modify them under the terms of the GNU
General Public License, Version 2, as published by the Free
Software Foundation.

These utilities are distributed in the hope that they will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with the book; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston,
MA  02111-1307  USA

The license is also available on the World Wide Web at
http://www.gnu.org/licenses/gpl.html

*/

//  Common header files
#include "BlasterIncludes.h"

//  Constructor with field number and grammar Element
DataCellAN::DataCellAN(int iFieldNumberIn,
    IXMLDOMElementPtr spGrammarIn) :
  DataCell(iFieldNumberIn, spGrammarIn) { }

//  Destructor
DataCellAN::~DataCellAN() {};


//  Uses base class fromXML

//  Prepare output for legacy format
//  This method developed in Chapter 8
int DataCellAN::prepareOutput()
{
  char cLength[5];
  char cTruncate[8];
  int iLength = 0;
  int iMinLength = 0;
  _variant_t vLength;

  memset(cLength,0,sizeof(cLength));
  memset(cTruncate,0,sizeof(cTruncate));

  //  Length <- Call Grammar Element's getAttribute for
  //    "Length"
  //  We may have Length or MinLength - With MSXML we get
  //  a variant and have to check if it is null
  vLength = spGrammar->getAttribute("Length");
  if (vLength.vt != VT_NULL)
  {
    strcpy(cLength,_bstr_t(vLength));
    if (strlen(cLength) > 0)
    {
      iLength = atoi(cLength);
      iMinLength = iLength;
    }
  }
  else
  {
    strcpy(cLength,
      _bstr_t(spGrammar->getAttribute("MinLength")));
    iMinLength = atoi(cLength);
  }

  //  Call fillField, passing L for left justification, and
  //    Length
  fillField('L', iMinLength);

  //  IF ( Length = 0 )
  if (iLength == 0)
  {
    //  Maximum Length <- Call Grammar Element's getAttribute
    //    for "MaxLength"
    memset(cLength,0,sizeof(cLength));
    strcpy(cLength,
        _bstr_t(spGrammar->getAttribute("MaxLength")));
    //  Length <- Maximum Length, converted from string
    iLength = atoi(cLength);
  } //  ENDIF

  //  IF (Cell Buffer Length <= Length)
  if (iBufferLength <= iLength)
  {
    //  Return success
    return SUCCESS;
  } //  ENDIF

  //  Truncate <- Call Grammar Element's getAttribute for
  //    "Truncatable"
  strcpy(cTruncate,
      _bstr_t(spGrammar->getAttribute("Truncatable")));

  //  IF ( Truncate == false )
  if (!strcmp(cTruncate,"false"))
  {
    //  Return error
    cerr << NO_TRUNCATION << endl
         << _bstr_t(spGrammar->getAttribute("ElementName"))
         <<  " " << iLength << endl
         << cCellBuffer << endl;
    return FAILURE;
  } //  ENDIF

  //  Depending on laguage features, truncate Cell Buffer
  //    contents to specified Length
  memset(&(cCellBuffer[iLength]), 0, (iBufferLength - iLength));

  //  Cell Buffer Length <- Length
  iBufferLength = iLength;

  //  Return success
  return SUCCESS;
}

int DataCellAN::toXML()
{
  //  Trim whitespace
  trim();
  return SUCCESS;
}
