/* DataCellDateYYYYMMDD.cpp

For handling of Date data type in YYYYMMDD format
fields in non-XML files

From Chapter 8 of
Using XML with Legacy Business Applications
Copyright (c) 2002 Addison-Wesley Professional

Author: Michael C. Rawlins
Rawlins EC Consulting
PMB 29
14 Canyon Creek Village
Richardson, TX 75080-1602
mike@rawlinsecconsulting.com
972-783-9573

This file is one of several utilities developed for the book.

All utilities developed for the book are free software; you can
redistribute and/or modify them under the terms of the GNU
General Public License, Version 2, as published by the Free
Software Foundation.

These utilities are distributed in the hope that they will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with the book; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston,
MA  02111-1307  USA

The license is also available on the World Wide Web at
http://www.gnu.org/licenses/gpl.html

*/

//  Common header files
#include "BlasterIncludes.h"

//  Constructor with field number and grammar Element
DataCellDateYYYYMMDD::DataCellDateYYYYMMDD(int iFieldNumberIn,
    const IXMLDOMElementPtr spGrammarIn) :
  DataCell(iFieldNumberIn, spGrammarIn) { }

//  Destructor
DataCellDateYYYYMMDD::~DataCellDateYYYYMMDD() {};


//  Convert from ISO YYYY-MM-DD to YYYYMMDD
int DataCellDateYYYYMMDD::fromXML()
{
  //  Locals
  char cTarget[11];
  memset(cTarget,0,sizeof(cTarget));

  //  IF length of CellBuffer != 10
  if (strlen(cCellBuffer) != 10)
  {
    //  Return error
    cerr << BAD_DATE << cCellBuffer << endl;
    return FAILURE;
  } //  ENDIF

  //  Month <- CellBuffer characters at offsets 5 and 6
  //  Day <- CellBuffer characters at offsets 8 and 9
  //  Year <- CellBuffer characters at offsets 0 through 3
  //  CellBuffer <- Year + Month + Day
  strncpy(cTarget,cCellBuffer,4);
  strncat(cTarget,&(cCellBuffer[5]),2);
  strncat(cTarget,&(cCellBuffer[8]),2);

  //  CellBuffer <- TempBuffer
  putField(cTarget,8);

  return SUCCESS;
}

//  Prepare output for legacy format
int DataCellDateYYYYMMDD::prepareOutput()
{
  char cLength[5];
  int iLength = 0;
  int iMinLength = 0;
  _variant_t vLength;

  memset(cLength,0,sizeof(cLength));

  //  Length <- Call Grammar Element's getAttribute for
  //    "Length"
  //  We may have Length or MinLength - With MSXML we get
  //  a variant and have to check if it is null
  vLength = spGrammar->getAttribute("Length");
  if (vLength.vt != VT_NULL)
  {
    strcpy(cLength,_bstr_t(vLength));
    if (strlen(cLength) > 0)
    {
      iLength = atoi(cLength);
      iMinLength = iLength;
    }
  }
  else
  {
    strcpy(cLength,
      _bstr_t(spGrammar->getAttribute("MinLength")));
    iMinLength = atoi(cLength);
  }

  //  Call fillField, passing L for left justification, and
  //    Length
  fillField('L', iMinLength);

  //  Return success
  return SUCCESS;
}

//  Convert from YYYYMMDD to ISO YYYY-MM-DD
int DataCellDateYYYYMMDD::toXML()
{

  //  Locals
  char cTarget[11];
  char cYear[5];
  char cMonth[3];
  char cDay[3];
  memset(cTarget,0,sizeof(cTarget));
  memset(cYear,0,sizeof(cYear));
  memset(cMonth,0,sizeof(cMonth));
  memset(cDay,0,sizeof(cDay));

  //  CellBuffer < trim leading and trailing white space from
  //    CellBuffer
  trim();

  //  IF length of CellBuffer != 8
  if ( iBufferLength != 8)
  {
    //  Return error
    cerr << BAD_DATE << cCellBuffer << endl;
    return FAILURE;
  } //  ENDIF

  //  Year <- CellBuffer characters at offsets 0 through 3
  //  Month <- CellBuffer characters at offsets 4 and 5
  //  Day <- CellBuffer characters at offsets 6 and 7
  //  CellBuffer <- Year + "-" + Month + "-" + Day

  strncpy(cYear,cCellBuffer,4);
  strncpy(cMonth,&(cCellBuffer[4]),2);
  strncpy(cDay,&(cCellBuffer[6]),2);
  strcpy(cTarget,cYear);
  strcat(cTarget,"-");
  strcat(cTarget,cMonth);
  strcat(cTarget,"-");
  strcat(cTarget,cDay);

  putField(cTarget,10);

  return SUCCESS;
}
