/* DataCellX12N.cpp

DataCell derived class for X12 Numeric data type

From Chapter 9 of
Using XML with Legacy Business Applications
Copyright (c) 2002 Addison-Wesley Professional

Author: Michael C. Rawlins
Rawlins EC Consulting
PMB 29
14 Canyon Creek Village
Richardson, TX 75080-1602
mike@rawlinsecconsulting.com
972-783-9573

This file is one of several utilities developed for the book.

All utilities developed for the book are free software; you can
redistribute and/or modify them under the terms of the GNU
General Public License, Version 2, as published by the Free
Software Foundation.

These utilities are distributed in the hope that they will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with the book; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston,
MA  02111-1307  USA

The license is also available on the World Wide Web at
http://www.gnu.org/licenses/gpl.html

*/

//  Common header files
#include "BlasterIncludes.h"

//  Constructor with field number and grammar Element
DataCellX12N::DataCellX12N(int iFieldNumberIn,
    IXMLDOMElementPtr spGrammarIn) :
  DataCellN(iFieldNumberIn, spGrammarIn) { }

//  Destructor
DataCellX12N::~DataCellX12N() {};

//  Uses base class fromXML and toXML

//  Prepare output for legacy format
//  In X12 we don't have a plus sign, and a leading minus
//  sign is not included in the length
int DataCellX12N::prepareOutput()
{
  char cMinLength[5], cMaxLength[5];
  int iMinLength, iMaxLength;
  //  NegativeNumber <- false
  bool boNegativeNumber = false;

  //  IF first character in CellBuffer is "-"
  if (cCellBuffer[0] == '-')
  {
    //  CellBuffer <- Shift CellBuffer left one character to
    //  remove Minus sign
    strcpy(cCellBuffer,&(cCellBuffer[1]));
    iBufferLength--;
    cCellBuffer[iBufferLength] = 0;
    //  NegativeNumber <- true
    boNegativeNumber = true;
  } //  ENDIF

  //  Minimum Length <- Call Grammar Element's getAttribute for
  //    "MinLength"
  strcpy(cMinLength, _bstr_t(spGrammar->getAttribute("MinLength")));
  iMinLength = atoi(cMinLength);

  //  IF ( Cell Buffer Length < Minimum Length )
  //  Call justifyFieldRight, passing Minimum Length and zero
  //    as Fill Character
  //  ENDIF
  if (iBufferLength < iMinLength)
  {
    justifyFieldRight(iMinLength,'0');
  }

  //  Maximum Length <- Call Grammar Element's getAttribute
  //    for "MaxLength"
  memset(cMaxLength,0,sizeof(cMaxLength));
  strcpy(cMaxLength,
      _bstr_t(spGrammar->getAttribute("MaxLength")));
  //  Length <- Maximum Length, converted from string
  iMaxLength = atoi(cMaxLength);

  //  IF (Cell Buffer Length > Length)
  if (iBufferLength > iMaxLength)
  {
    //  Return error
    cerr << NO_TRUNCATION << endl
         << _bstr_t(spGrammar->getAttribute("ElementName"))
         <<  " " << iMaxLength << endl
         << cCellBuffer << endl;
    return FAILURE;
  } //  ENDIF

  //  IF NegativeNumber = true
  if (boNegativeNumber)
  {
    //  CellBuffer <- Shift CellBuffer right one character to
    //    insert Minus sign
    //  Increment Cell Buffer Length
    strcpy(&(cCellBuffer[1]),cCellBuffer);
    cCellBuffer[0] = '-';
    iBufferLength++;
  } //  ENDIF

  //  Return success
  return SUCCESS;

}
