/* TextConstants.h

Defines constants for common information and error messages

From Chapter 6 of
Using XML with Legacy Business Applications
Copyright (c) 2002 Addison-Wesley Professional

Author: Michael C. Rawlins
Rawlins EC Consulting
PMB 29
14 Canyon Creek Village
Richardson, TX 75080-1602
mike@rawlinsecconsulting.com
972-783-9573

This file is one of several utilities developed for the book.

All utilities developed for the book are free software; you can
redistribute and/or modify them under the terms of the GNU
General Public License, Version 2, as published by the Free
Software Foundation.

These utilities are distributed in the hope that they will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with the book; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston,
MA  02111-1307  USA

The license is also available on the World Wide Web at
http://www.gnu.org/licenses/gpl.html

*/

#ifndef TEXTCONSTANTS_H
#define TEXTCONSTANTS_H

//  Constants for displayParseError.cpp
#define PARSE_ERROR_REASON        "Reason"
#define PARSE_ERROR_SOURCE        "Source Text"
#define PARSE_ERROR_URL           "File URL"
#define PARSE_ERROR_FILE_POSITION "Position in file"
#define PARSE_ERROR_LINE          "Line            "
#define PARSE_ERROR_LINE_POSITION "Position in line"

//  Constants for handleCOMError.cpp
#define COM_ERROR_HEADER        "COM Error"
#define COM_ERROR_CODE          "Code"
#define COM_ERROR_MESSAGE       "Message"
#define COM_ERROR_SOURCE        "Source"
#define COM_ERROR_DESCRIPTION   "Description"

//  Messages for IO Errors
#define IO_READ_ERROR_MESSAGE \
  "Error in reading input file "
#define IO_OUTPUT_OPEN_ERROR_MESSAGE \
  "Failure in opening output file "
#define IO_DIRECTORY_OPEN_ERROR_MESSAGE \
  "Failure in opening input directory "
#define IO_DIRECTORY_CREATE_ERROR_MESSAGE \
  "Failure in creating directory "


//  Standard Copyright and Information Message
//  Use this one as last option in listing

#define HELP_INFO_1 \
"  -h   Display this message and exit with no action\n\
\n\
Copyright (c) 2002 Addison-Wesley Professional\n\
Author: Michael C. Rawlins, Rawlins EC Consulting\n\
\n"

//  Display the program name, then this second part
#define HELP_INFO_2 \
" comes with with ABSOLUTELY NO WARRANTY.\n\
This is free software and you are welcome to\n\
redistribute it under certain conditions.\n\
Refer to the GNU General Public License for details.\n"


//  Usage and Help for CSV to XML
#define CSV_TO_XML_USAGE \
"Usage: CSVToXML InputFile.CSV OutputDirectory \
FileDescriptionDocument.xml options \n\
or CSVToXML -h"
#define CSV_TO_XML_HELP \
"\n\
Converts an input comma separated value file into one\n\
or more output XML documents in the output directory\n\
\n\
Arguments:\n\
  InputFile.CSV                Input CSV file\n\
  OutputDirectory              Output directory path\n\
  FileDescriptionDocument.xml  File Description Document\n\
\n\
Options:\n\
  -v   Validate output documents before writing them\n"

//  Usage and Help for XML to CSV
#define XML_TO_CSV_USAGE \
"Usage: XMLToCSV InputDirectory OutputFile.CSV  \
FileDescriptionDocument.xml options \n\
or XMLToCSV -h"
#define XML_TO_CSV_HELP \
"\n\
Converts one or more input XML documents in the input\n\
directory to an output comma separated value file\n\
\n\
Arguments:\n\
  InputDirectory               Input directory path\n\
  OutputFile.CSV               Output CSV file\n\
  FileDescriptionDocument.xml  File Description Document\n\
\n\
Options:\n\
  -v   Validate input documents\n"

//  Usage and Help for Flat to XML
#define FLAT_TO_XML_USAGE \
"Usage: FlatToXML InputFile.dat OutputDirectory \
FileDescriptionDocument.xml options \n\
or FlatToXML -h"
#define FLAT_TO_XML_HELP \
"\n\
Converts an input flat file into one or more output\n\
XML documents in the output directory\n\
\n\
Arguments:\n\
  InputFile.dat                Input flat file\n\
  OutputDirectory              Output directory path\n\
  FileDescriptionDocument.xml  File Description Document\n\
\n\
Options:\n\
  -v   Validate output documents before writing them\n"
  
//  Usage and Help for XML to Flat
#define XML_TO_FLAT_USAGE \
"Usage: XMLToFlat InputDirectory OutputFile.dat  \
FileDescriptionDocument.xml options \n\
or XMLToFlat -h"
#define XML_TO_FLAT_HELP \
"\n\
Converts one or more input XML documents in the input\n\
directory to an output flat file\n\
\n\
Arguments:\n\
  InputDirectory               Input directory path\n\
  OutputFile.dat               Output flat file\n\
  FileDescriptionDocument.xml  File Description Document\n\
\n\
Options:\n\
  -v   Validate input documents\n"

//  Usage and Help for X12 to XML
#define X12_TO_XML_USAGE \
"Usage: X12ToXML InputFile.x12 OutputDirectory \
FileDescriptionDocumentPath options \n\
or X12ToXML -h"
#define X12_TO_XML_HELP \
"\n\
Converts an input X12 interchange into one or more output\n\
XML documents in the output directory\n\
\n\
Arguments:\n\
  InputFile.x12                Input X12 interchange\n\
  OutputDirectory              Output directory path\n\
  FileDescriptionDocumentPath  \
Directory path for File Description Documents\n\
\n\
Options:\n\
  -v   Validate output documents before writing them\n"
  
//  Usage and Help for XML to X12
#define XML_TO_X12_USAGE \
"Usage: XMLToX12 InputDirectory OutputFile.x12  \
FileDescriptionDocument.xml options \n\
or XMLToX12 -h"
#define XML_TO_X12_HELP \
"\n\
Converts one or more input XML documents in the input\n\
directory to an X12 EDI interchange\n\
\n\
Arguments:\n\
  InputDirectory               Input directory path\n\
  OutputFile.x12               Output X12 interchange\n\
  FileDescriptionDocument.xml  File Description Document\n\
\n\
Options:\n\
  -v   Validate input documents\n"

//  Progress messages
#define PROCESSING_DOCUMENT "Processing document..."
#define CREATING_DOCUMENT "Creating document..."

//  Completion messages
#define TERMINATION_NORMAL "Normal completion"
#define ABEND "Abnormal Termination"
#define DOCUMENTS_PROCESSED " Documents Processed"

//  Constants for XML prolog
#define XML_PROLOG_TEXT  "version=\"1.0\" encoding=\"UTF-8\""


//  Common error messages
#define COM_INIT_ERROR \
  "Failed to initialize COM environment"
#define CREATE_INSTANCE_ERROR \
  "Failed to create Document instance"
#define INSTANCE_SAVE_ERROR \
  "Failed to save XML document "
#define INPUT_FILE_OPEN_ERROR \
  "Failure in opening input file "
#define UNEXPECTED_EXCEPTION \
  "Unexpected char exception "
#define XML_OUTPUT_SAVE_ERROR \
  "Failure in saving output XML Document: "

#define PARSE_ERROR_BRIEF "Parsing Error of "
#define VALIDATION_ERROR_BRIEF "Validation Error of "
#define VALIDATION_WITHOUT_SCHEMA \
  "Error - Validation invalid with no schema URL specified"
#define ARRAY_OVERFLOW_IN "Error - Array index out of range in "
#define BUFFER_OVERFLOW_IN "Error - Buffer overflow in "
#define UNSUPPORTED_DATA_TYPE "Error - Unsupported data type : "
#define NO_FIELD \
  "Error - Requested field number not present in record: "
#define BAD_DATE "Error - Date field in incorrect format: "
#define BAD_TIME "Error - Time field in incorrect format: "
#define NOT_IN_DOCUMENT_GRAMMAR \
  "Record or Group Element not in Document Grammar: "
#define RECORD_NOT_IN_GROUP_GRAMMAR \
   " Element not in group grammar for " 
#define FIELD_ELEMENT_NOT_IN_RECORD_GRAMMAR \
  " Field Element not in Record Grammar for "
#define FIELD_NOT_IN_RECORD_GRAMMAR \
  " Field not in Record Grammar for "
#define ROOT_MISMATCH \
" Input Document Root Element Name not same as Grammar Root \
Element Name of "
#define CSV_PARSING_ERROR \
"Error in parsing CSV input record : \n"
#define MAX_SEQUENCE_EXCEEDED \
"Error - maximum sequence number exceeded : "
#define NO_FIELD_FIXED \
"Requested field with offset and length not present in record: "
#define NOT_HEADER_TAG \
" record tag is unknown, not in the specified sequence, \
or not the specified header record tag of "
#define NO_TRUNCATION \
"Error - element content longer than destination field \
and truncation not allowed"

#define UNSUPPORTED_SPECIAL_VALUE \
"Error - unsupported special value for Element data type: "
#define NO_SEGMENT_TAG \
"Error - no segment tag in input segment: "
#define EDI_PARSING_ERROR "Error parsing EDI segment: "
#define POSITION_IN_SEGMENT "Element position in segment: "
#define POSITION_IN_COMPOSITE \
"Component element position in composite: "
#define CHARACTER_POSITION_IN_SEGMENT \
"Character position in segment: "
#define NOT_INTERCHANGE_HEADER \
"Error - Not an interchange header segment for "
#define INSUFFICIENT_ELEMENTS \
"Error - insufficient elements in control segment: "
#define INVALID_INTERCHANGE \
"Error - invalid interchange, missing required control \
segments: "
#define BBHOME_NOT_SET \
"Error - BBHOME environment variable not set "

#endif
